Parameters — miml documentation

Skip to main content
`Ctrl`+`K`

# Parameters

class miml.transformation.mimlTOml.minmax.MinMaxTransformation

  Bases: `MIMLtoMLTransformation`

  Class that performs a minmax transformation to convert a MIMLDataset class to numpy ndarray.

  transform_bag(bag: Bag)

    Transform a bag to a multilabel instance

    # Parameters

    bagBag

      Bag to be transformed to multilabel instance

    # Returns

    transformed_bagBag

      Transformed bag

  transform_dataset(dataset: MIMLDataset)

    Transform the dataset to multilabel dataset converting each bag into a single instance with the min and max value of each attribute as two new attributes.

    # Returns

    Xndarray of shape (n_bags, n_features*2)

      Training vector

    Yndarray of shape (n_bags, n_labels)

      Target vector relative to X.